# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.1] - 03-02-2025

### Added

- Various classifiers and descriptive URLs to `pyproject.toml`

### Changed

- Only build wheels for supported Python versions 3.9 - 3.12

## [0.1.0] - 01-10-2024

### Added

- Initial release
